from skeleton.settings_live_base import *


FOUNDRY['layers'] = ('smart', 'basic',)
SITE_ID = 4
